<?php

/**
* weeblrAMP - Accelerated Mobile Pages for Wordpress
*
* @author weeblrPress
* @copyright (c) WeeblrPress - Weeblr,llc - 2017
* @package weeblrAMP
* @license http://www.gnu.org/copyleft/gpl.html GNU/GPL
* @version 1.8.0.620
*
* 2017-09-20
*/
$submitClass = realpath( __DIR__ . '/class-amp-cf7-submission.php' );
if ( file_exists( $submitClass ) ) {
	include_once $submitClass;
} else {
	@header( 'HTTP/1.1 500 INTERNAL ERROR' );
	exit;
}

class AMP_Contact_Form_Submit extends AMP_Form_Submit {
	protected $action  = '';
	protected $formId  = 0;
	protected $cf7Vars = array(
		'_wpcf7',
		'_wpcf7_version',
		'_wpcf7_locale',
		'_wpcf7_unit_tag',
	);
	public function amp_cf7_send_json( $items, $result ) { 
		$status                    = isset( $result['status'] ) ? $result['status'] : '';
		$this->response['message'] = isset( $result['message'] ) ? $result['message'] : '';
		if ( ! empty( $result['invalid_fields'] ) ) {
			$errors = array();
			foreach ( $result['invalid_fields'] as $error ) {
				if ( ! empty( $error['reason'] ) ) {
					$errors[] = array( 'error_detail' => $error['reason'] );
				}
			}
			if ( ! empty( $errors ) ) {
				$this->response['errors']     = $errors;
				$this->response['has_errors'] = true;
			}
		}
		switch ( $status ) {
			case 'mail_failed':
				$this->response['status'] = 'error';
				$this->outputResponse()
				     ->pushResponse( 'HTTP/1.1 500 FORBIDDEN' );
				break;
			case 'mail_sent':
				$this->response['status'] = 'success';
				$this->outputResponse()
				     ->pushResponse();
				break;
			default:
				$this->response['status'] = 'error';
				$this->outputResponse()
				     ->pushResponse( 'HTTP/1.1 403 FORBIDDEN' );
				break;
		}
	}
	protected function preProcess() {
		parent::preProcess();
		if ( ! empty( $this->request['action'] ) ) {
			$this->action = $this->request['action'];
		}
		foreach ( $this->cf7Vars as $var ) {
			unset( $_POST[ $var ] );
			unset( $_REQUEST[ $var ] );
		}
		return $this;
	}
	protected function setHooks() {
		parent::setHooks();
		add_filter( 'wpcf7_ajax_json_echo', array( $this, 'amp_cf7_send_json' ),10, 2 );
		/*Flamingo: 
		Need to change the below hook in order to submit the Data to Flamingo's Database even if the Page Re-direction is set */
		//add_action( 'wpcf7_mail_sent', array( $this, 'non_ajax_redirection' ) );
		global $cf7_redirect;
		// Removed their Redirection and made our Redirection (AMP-Redirect-To) to work.
		remove_action( 'wpcf7_submit', array( $cf7_redirect, 'non_ajax_redirection' ) );
		add_action( 'wpcf7_submit', array($this, 'ampforwp_cf7_redirect') );
		if(is_plugin_active('contact-form-7-multi-step-module/contact-form-7-multi-step-module.php')){
		add_action( 'wpcf7_submit', array($this, 'ampforwp_cf7_multistep') );
		}
		add_filter( 'wpcf7_special_mail_tags', array($this,'ampforwpcf7_special_mail_tag'), 10, 3 );
	
		return $this;
	}
	public function ampforwpcf7_special_mail_tag($output, $name, $html){
		$name = preg_replace( '/^wpcf7\./', '_', $name ); // for back-compat
 
		$amp_url = '';
 
		if ( '_remote_ip' == $name ) {
			$ip_addr = '';
			if ( isset( $_SERVER['REMOTE_ADDR'] )
			&& WP_Http::is_ip_address( $_SERVER['REMOTE_ADDR'] ) ) {
				$ip_addr = $_SERVER['REMOTE_ADDR'];
			}
			if ( $ip_addr ) {
				return $ip_addr;
			} else {
				return '';
			}
		}

		if ( '_user_agent' == $name ) {

			$ampforwp_user_agent = isset( $_SERVER['HTTP_USER_AGENT'] )
					? substr( $_SERVER['HTTP_USER_AGENT'], 0, 254 ) : '';

			if ( $ampforwp_user_agent) {
				return $html ? esc_html( $ampforwp_user_agent ) : $ampforwp_user_agent;
			} else {
				return '';
			}
		}

		if ( '_url' == $name ) { 

			$amp_url = esc_url(trim( $_SERVER['HTTP_REFERER'] ));

			return $amp_url;
	 
		}

		if ( '_date' == $name || '_time' == $name ) {
			$timestamp = current_time( 'timestamp' );
			if ( $timestamp ) {

				if ( '_date' == $name ) {
					return date_i18n( get_option( 'date_format' ), $timestamp );
				}
				if ( '_time' == $name ) {
					return date_i18n( get_option( 'time_format' ), $timestamp );
				}
			}
			return '';
		}

		if ( '_post_' == substr( $name, 0, 6 ) ) {

			$post_id = url_to_postid(esc_url(trim( $_SERVER['HTTP_REFERER'] )));  

			if ( $post = get_post( $post_id ) ) {
				if ( '_post_id' == $name ) {
					return (string) $post->ID;
				}

				if ( '_post_name' == $name ) {
					return $post->post_name;
				}

				if ( '_post_title' == $name ) {

					return $html ? esc_html( $post->post_title ) : $post->post_title;
				}

				if ( '_post_url' == $name ) {
					return get_permalink( $post->ID );
				}

				$user = new WP_User( $post->post_author );

				if ( '_post_author' == $name ) {
					return $user->display_name;
				}

				if ( '_post_author_email' == $name ) {
					return $user->user_email;
				}
			}

			return '';
		}

		return $output;
			 
 	}
 
 	public function ampforwp_cf7_multistep($test){
 		global $redux_builder_amp;
 		$ampforwp_redirect_page = "";
 		if(is_plugin_active('contact-form-7-multi-step-module/contact-form-7-multi-step-module.php')){
	 	$wpcf7 = WPCF7_ContactForm::get_current();
    	$ampforwp_redirect_page = parse_form_for_multistep( $wpcf7 );
    	}
    	if(!empty($ampforwp_redirect_page)){
    		$ampforwp_redirect_page = ($redux_builder_amp['amp-core-end-point'] == 0 ) ? $ampforwp_redirect_page.'amp/' : $ampforwp_redirect_page.'?amp';
    	}	
    	if($this->response['error'] == 'Found' || $this->response['emailerror'] == 'emailerror'){
			   if($this->response['error'] == 'Found' && $this->response['emailerror'] == 'emailerror'){
			   	   if($redux_builder_amp['amp-cf7-Please-fill-all-the'] !== ""){
						   $text = $redux_builder_amp['amp-cf7-Please-fill-all-the'];
					}else{$text = "Please fill all the required Fields with Valid Email Format";
				    }
                $this->response['message'] = $text;
			   }
			   else{
				   if($this->response['error'] == 'Found'){
					   	if($redux_builder_amp['amp-cf7-fill-the-fields'] !== ""){
							$warningwithoutemail = $redux_builder_amp['amp-cf7-fill-the-fields'];
						}else{$warningwithoutemail = "Please fill all the required Fields";
					    }
				     $this->response['message'] = $warningwithoutemail;
				      }
	               if($this->response['emailerror'] == 'emailerror'){
				    $this->response['message'] = "Invalid Email Format";
				   }
			   }
			  header('HTTP/1.1 500 FORBIDDEN');
			}
			else{
    	  	$ampforwp_cf7_redirect = str_replace('http:', 'https:', $ampforwp_redirect_page);
    	  	$this->cors_Headers['AMP-Redirect-To'] = $ampforwp_cf7_redirect; 
			$this->cors_Headers['Access-Control-Expose-Headers'] = "AMP-Redirect-To, ".$this->cors_Headers['Access-Control-Expose-Headers'];
			if($redux_builder_amp['amp-cf7-success-msg'] !== ""){
				$cf7_success_msg = $redux_builder_amp['amp-cf7-success-msg'];
			}else{$cf7_success_msg = "Thank you, your form has been submitted";
		    }
			$this->response['message'] = $cf7_success_msg;
			}
			$this->outputResponse()->pushResponse();
			exit;
 	}

	public function ampforwp_cf7_redirect($contact_form) {
	    $theme = wp_get_theme();
		if($theme['Name'] == 'Elite agency'){
		    if(class_exists('WPCF7_ContactForm')){
				$wpcf7 = WPCF7_ContactForm::get_current();
				$form_id = $wpcf7->id;
				if($form_id == 1131){
					if(class_exists('WPCF7_Submission')){
						$submission = WPCF7_Submission::get_instance(); 
					    $posted_data = $submission->get_posted_data();
					    $email = $posted_data['your-email'];
					    $emailConfirm = $posted_data['your-email-confirm'];
			
					    if($email !== $emailConfirm){
					    	header('HTTP/1.1 500 FORBIDDEN');
					    	 echo json_encode(array('message'=>'Are You Sure You Have Enter Correct Email address? Please Enter again.'));
					        die();
					    }
				    }

				}
		    }
			if(class_exists('ReallySimpleCaptcha')){
			    	$captchaName = $_POST['captcha-1'];
				    if(empty($captchaName)){
				     header('HTTP/1.1 500 FORBIDDEN');
				     echo json_encode(array('message'=>'Your entered code is incorrect.'));
				     die();
				    }
			}    
		    
		}
		global $redux_builder_amp;
		include_once( ABSPATH . 'wp-admin/includes/plugin.php' );
		$contact_form_id = $contact_form->id();
		$required_terms = $contact_form->scan_form_tags();
        $this->response['error'] = "No";
		foreach ($required_terms as $reqkey => $reqvalue) {
			if(strpos($reqvalue->type, '*')  ){
			    if(empty($_POST[$reqvalue->name])){
                $this->response['error'] = "Found";
			    }
			    if($reqvalue->basetype == 'email' && !strpos($_POST["$reqvalue->name"], '@') ){
                     $this->response['emailerror'] = "emailerror";
		    	}
		 	}
        }
        if(isset($redux_builder_amp['amp-cf7-redirection-main-switch']) && $redux_builder_amp['amp-cf7-redirection-main-switch'] == true){
        $get_cf7_amp_redirect_id = $get_cf7_amp_redirect_url = '';
        $cf7_success_msg = $redux_builder_amp['amp-cf7-success-msg'] !== "" ? $redux_builder_amp['amp-cf7-success-msg'] : "Thank you form has been submitted, Please wait....";
        if( $redux_builder_amp['amp-cf7-redirection-int-switch'] == true ){
            $get_cf7_amp_redirect_id = $redux_builder_amp['amp-cf7-redirection-select-option'];
            $get_cf7_amp_redirect_url = get_permalink($get_cf7_amp_redirect_id);
        }
        elseif( $redux_builder_amp['amp-cf7-redirection-ext-switch'] == true ){
            $get_cf7_amp_redirect_url = $redux_builder_amp['amp-cf7-redirection-ext-url'];
        }
		$success_page_url = $success_page_ext = $get_success_page_url = $ampforwp_with_wpcf7_redirect = '';
    	$success_page = (is_plugin_active('contact-form-7-success-page-redirects/cf7-success-page-redirects.php') ? get_post_meta( $contact_form_id, '_cf7_success_page_key', true ) : '' );
		if(is_plugin_active('wpcf7-redirect/wpcf7-redirect.php')){

			$get_success_page_url = new WPCF7_Redirect();
			$success_page_ext = $get_success_page_url->get_fields_values($contact_form_id);
			if(!empty($success_page_ext['page_id'])) {
				$success_page_url = get_permalink($success_page_ext['page_id']);
			}
		}

 		if ( !empty($get_cf7_amp_redirect_url) || (!empty($success_page_ext['external_url']) && 'on' == $success_page_ext['use_external_url'] ) || (!empty($success_page_ext['page_id'])) || (!empty($success_page)) || (isset($_POST['amp_redirect_url']) && !empty($_POST['amp_redirect_url'])) ) {

 			$ampforwp_with_wpcf7_redirect = ( !empty($success_page_ext['page_id']) ? $success_page_url : $success_page_ext['external_url'] );
    	  	$ampforwp_redirect_page = (!empty($ampforwp_with_wpcf7_redirect) ? $ampforwp_with_wpcf7_redirect : get_permalink( $success_page ) );
    	  	$ampforwp_redirect_page = !empty($get_cf7_amp_redirect_url) ? $get_cf7_amp_redirect_url : $ampforwp_redirect_page;

			if($this->response['error'] == 'Found' || $this->response['emailerror'] == 'emailerror'){
			   if($this->response['error'] == 'Found' && $this->response['emailerror'] == 'emailerror'){
                $this->response['message'] = ($redux_builder_amp['amp-cf7-Please-fill-all-the'] !== "") ? $redux_builder_amp['amp-cf7-Please-fill-all-the'] : 'Please fill all the required Fields with Valid Email Format';
			   }
			   else{
				   if($this->response['error'] == 'Found'){
				     $this->response['message'] = ($redux_builder_amp['amp-cf7-fill-the-fields'] !== "") ? $redux_builder_amp['amp-cf7-fill-the-fields'] : 'Please fill all the required Fields';
				      }
	               if($this->response['emailerror'] == 'emailerror'){
				    $this->response['message'] = "Invalid Email Format";
				   }
			   }
			  header('HTTP/1.1 500 FORBIDDEN');
			}
			else{
				if(isset($_POST['amp_redirect_url']) && !empty($_POST['amp_redirect_url'])){
					$ampforwp_redirect_page = $_POST['amp_redirect_url'];
				}
    	  	$ampforwp_cf7_redirect = str_replace('http:', 'https:', $ampforwp_redirect_page);
    	  	$this->cors_Headers['AMP-Redirect-To'] = $ampforwp_cf7_redirect; 
			$this->cors_Headers['Access-Control-Expose-Headers'] = "AMP-Redirect-To, ".$this->cors_Headers['Access-Control-Expose-Headers'];
			$this->response['message'] = $cf7_success_msg;
			}
			$this->outputResponse()->pushResponse();
			exit;
    	  }
    	}  
	}
	protected function submitForm() {
		$cf7Version = $this->getCf7Version();
		if ( version_compare( $cf7Version, '4.8', 'lt' ) ) {
			foreach ( $this->cf7Vars as $var ) {
				$_POST[ $var ]    = isset( $this->posted[ $var ] ) ? $this->posted[ $var ] : null;
				$_REQUEST[ $var ] = isset( $this->posted[ $var ] ) ? $this->posted[ $var ] : null;
			}
			wpcf7_ajax_json_echo();
		} else {
			$this->wpcf7SubmitForm();
		}
	}
	protected function wpcf7SubmitForm() {
		$id = ampforwp_get_array( $this->posted, '_wpcf7' );
		if ( empty( $id ) ) {
			$this->response['status'] = 'error';
			$this->outputResponse()
			     ->pushResponse( 'HTTP/1.1 404 NOT FOUND' );
		}
		$item = wpcf7_contact_form( $id );
		if ( ! $item ) {
			$this->response['status'] = 'error';
			$this->outputResponse()
			     ->pushResponse( 'HTTP/1.1 404 NOT FOUND' );
		}
		 global $redux_builder_amp;
         if(isset($redux_builder_amp['ampforwp-cf7-recaptcha']) && $redux_builder_amp['ampforwp-cf7-recaptcha'] == 1) {
	         $post_response = $_POST['cf7-recaptcha-response'];
	         $gglcptch_remote_addr = filter_var( $_SERVER['REMOTE_ADDR'], FILTER_VALIDATE_IP );
	         $secretkey = $redux_builder_amp['ampforwp-cf7-recaptcha-secerete']; 
		    $args = array(
		          'body' => array(
		            'secret'   => $secretkey,
		            'response' => stripslashes( esc_html( $post_response ) ),
		            'remoteip' => $gglcptch_remote_addr,
		          ),
		          'sslverify' => false
		        );
	         $resp = wp_remote_post( 'https://www.google.com/recaptcha/api/siteverify', $args );


	         $response =  json_decode( wp_remote_retrieve_body( $resp ), true );
	         
	         $expected_Response_Msg = array(
	          'missing-input-secret' => 'The secret parameter is missing.',
	          'invalid-input-secret'=> 'The secret parameter is invalid or malformed.',
	          'missing-input-response'=> 'The response parameter is missing.',
	          'invalid-input-response'=> 'The response parameter is invalid or malformed.',
	          'bad-request'=> 'The request is invalid or malformed.',
	          'timeout-or-duplicate'=> 'The response is no longer valid: either is too old or has been used previously.',

	            );

		     $result = array(
		              'response' => false,
		              'reason' => 'My changes'
		          );

		     if ( isset( $response['success'] ) ) {
		        if ($response['score'] > 0.5 ) {
		                    $result = array(
		                        'response' => true,
		                        'reason' => 'RECAPTCHA_SUCCESS'
		                    );
		        }
		     }else {
		        $result = array(
		              'response' => false,
		              'reason' => $response['error-codes']
		          );
		       }

	         if( $result['response'] == false){

				  //return new WP_Error('RECAPCTHA_INVALID', 'invalid recaptcha value',403 );
				  header("access-control-allow-credentials:true");
				  header("access-control-allow-headers:Content-Type, Content-Length, Accept-Encoding, X-CSRF-Token");
				  header("Access-Control-Allow-Origin:".$_SERVER['HTTP_ORIGIN']);
				  $siteUrl = parse_url(  get_site_url() );
				  header("AMP-Access-Control-Allow-Source-Origin:".$siteUrl['scheme'] . '://' . $siteUrl['host']);
				  header("access-control-expose-headers:AMP-Access-Control-Allow-Source-Origin");
				  header("Content-Type:application/json;charset=utf-8");
				  $comment_status = array('message' => $expected_Response_Msg[$response['error-codes'][0]] );
				  echo json_encode($comment_status);
				  $sapi_type = php_sapi_name();
				  if (substr($sapi_type, 0, 3) == 'cgi')
				    header("Status: 404 Not Found");
				  else
				    header("HTTP/1.1 404 Not Found");
				  die;
        	}
       	}
		$result = $item->submit();
		$unit_tag = ampforwp_get_array( $this->posted, '_wpcf7_unit_tag' );
		$response = array(
			'into'    => '#' . wpcf7_sanitize_unit_tag( $unit_tag ),
			'status'  => $result['status'],
			'message' => $result['message'],
		);
		if ( 'validation_failed' == $result['status'] ) {
			$invalid_fields = array();
			foreach ( (array) $result['invalid_fields'] as $name => $field ) {
				$invalid_fields[] = array(
					'into'    => 'span.wpcf7-form-control-wrap.'
					             . sanitize_html_class( $name ),
					'message' => $field['reason'],
					'idref'   => $field['idref'],
				);
			}
			$response['invalidFields'] = $invalid_fields;
		}
		$this->amp_cf7_send_json( $response, $result );
	}
	protected function run() {
		switch ( $this->action ) {
			case 'contact_form_submission'://'submit':
				$this->submitForm();
				break;
			default:
				$this->response['status'] = 'error';
				$this->outputResponse()
				     ->pushResponse( 'HTTP/1.1 404 NOT FOUND' );
				break;
		}
		return $this;
	}

	protected function getCf7Version() {
		$version = ampforwp_get_array( $this->posted, '_wpcf7_version' );
		if ( empty( $version ) && defined( 'WPCF7_VERSION' ) ) {
			$version = WPCF7_VERSION;
		}
		return $version;
	}
}
$amp_cf7_instantiate = new AMP_Contact_Form_Submit( $_GET, $_POST );
$amp_cf7_instantiate->activate();