<?php
/**
 * Include and setup custom metaboxes and fields. (make sure you copy this file to outside the CMB2 directory)
 *
 * Be sure to replace all instances of 'yourprefix_' with your project's prefix.
 * http://nacin.com/2010/05/11/in-wordpress-prefix-everything/
 *
 * @category YourThemeOrPlugin
 * @package  Demo_CMB2
 * @license  http://www.opensource.org/licenses/gpl-license.php GPL v2.0 (or later)
 * @link     https://github.com/WebDevStudios/CMB2
 */

/**
 * Get the bootstrap! If using the plugin from wordpress.org, REMOVE THIS!
 */

if ( file_exists( AMPOPTIN_METABOX_DIR . 'init.php' ) ) {
	require_once AMPOPTIN_METABOX_DIR . 'init.php';
} elseif ( file_exists( AMPOPTIN_PLUGIN_DIR . '/CMB2/init.php' ) ) {
	require_once AMPOPTIN_PLUGIN_DIR . '/CMB2/init.php';
}

/**
 * Conditionally displays a metabox when used as a callback in the 'show_on_cb' cmb2_box parameter
 *
 * @param  CMB2 object $cmb CMB2 object.
 *
 * @return bool             True if metabox should show
 */
function yourprefix_show_if_front_page( $cmb ) {
	// Don't show this metabox if it's not the front page template.
	if ( get_option( 'page_on_front' ) !== $cmb->object_id ) {
		return false;
	}
	return true;
}

/**
 * Conditionally displays a field when used as a callback in the 'show_on_cb' field parameter
 *
 * @param  CMB2_Field object $field Field object.
 *
 * @return bool                     True if metabox should show
 */
function yourprefix_hide_if_no_cats( $field ) {
	// Don't show this field if not in the cats category.
	if ( ! has_tag( 'cats', $field->object_id ) ) {
		return false;
	}
	return true;
}


/**
 * Manually render a field column display.
 *
 * @param  array      $field_args Array of field arguments.
 * @param  CMB2_Field $field      The field object.
 */
function yourprefix_display_text_small_column( $field_args, $field ) {
	?>
	<div class="custom-column-display <?php echo esc_attr( $field->row_classes() ); ?>">
		<p><?php echo $field->escaped_value(); ?></p>
		<p class="description"><?php echo esc_html( $field->args( 'description' ) ); ?></p>
	</div>
	<?php
}

/**
 * Conditionally displays a message if the $post_id is 2
 *
 * @param  array             $field_args Array of field parameters.
 * @param  CMB2_Field object $field      Field object.
 */
function yourprefix_before_row_if_2( $field_args, $field ) {
	if ( 2 == $field->object_id ) {
		echo '<p>Testing <b>"before_row"</b> parameter (on $post_id 2)</p>';
	} else {
		echo '<p>Testing <b>"before_row"</b> parameter (<b>NOT</b> on $post_id 2)</p>';
	}
}

add_action( 'cmb2_admin_init', 'yourprefix_register_demo_metabox' );
/**
 * Hook in and add a demo metabox. Can only happen on the 'cmb2_admin_init' or 'cmb2_init' hook.
 */
function yourprefix_register_demo_metabox() {
	$prefix = 'ampforwp_optin_';

	/**
	 * Sample metabox to demonstrate each field type included
	 */
	$cmb_object = new_cmb2_box( array(
		'id'            => $prefix . 'metabox',
		'title'         => esc_html__( 'Optin form Settings', 'cmb2' ),
		'object_types'  => array( 'amp-optin', ), // Post type
		// 'show_on_cb' => 'yourprefix_show_if_front_page', // function should return a bool value
		// 'context'    => 'normal',
		// 'priority'   => 'high',
		// 'show_names' => true, // Show field names on the left
		// 'cmb_styles' => false, // false to disable the CMB stylesheet
		// 'closed'     => true, // true to keep the metabox closed by default
		// 'classes'    => 'extra-class', // Extra cmb2-wrap classes
		// 'classes_cb' => 'yourprefix_add_some_classes', // Add classes through a callback.
	) );


	$cmb_object->add_field( array(
		'name' => 'Newsletter Company',
		'desc' => 'Select the newsletter opt-in company which you want integrate',
		'type' => 'title',
		'id'   => 'amp_optin_company_title',
	) );

	$cmb_object->add_field( array(
			'name'             => esc_html__( 'Company', 'ampforwp_optin' ),
			'id'               => 'amp_optin_select_form_company',
			'type'             => 'select',
			'show_option_none' => false,
			'options'          => array(
				'1'   => esc_html__( 'MailChimp', 'ampforwp_optin' ),
				'2'   => esc_html__( 'GetResponse', 'ampforwp_optin' ),
				'3'   => esc_html__( 'Campagin Monitor', 'ampforwp_optin' ),
				'4'   => esc_html__( 'Mailerlite', 'ampforwp_optin' ),
				'5'   => esc_html__( 'Active Campaign', 'ampforwp_optin' ),
				'6'   => esc_html__( 'Sendy', 'ampforwp_optin' ),
				'7'   => esc_html__( 'ConvertKit', 'ampforwp_optin' ),
				'8'   => esc_html__( 'AWeber', 'ampforwp_optin' ),
				'9'   => esc_html__( 'RD Station', 'ampforwp_optin' ),
				'10'  => esc_html__( 'MailPoet', 'ampforwp_optin' ),
				'11'  => esc_html__('Benchmark','ampforwp_optin'),
				'12'  => esc_html__('GetDrip','ampforwp_optin'),
				'13'  => esc_html__('Mautic','ampforwp_optin'),
				'14'  => esc_html__('SendinBlue','ampforwp_optin'),
				'15'  => esc_html__('Ontraport','ampforwp_optin'),
				'16'  => esc_html__('Sharp Spring','ampforwp_optin'),
				'17'  => esc_html__('E-goi','ampforwp_optin'),
				'18'  => esc_html__('MailJet','ampforwp_optin'),
				'19'  => esc_html__('iPost','ampforwp_optin'),
				'20'  => esc_html__('Infusionsoft','ampforwp_optin'),
				'21'  => esc_html__('ConstantContact','ampforwp_optin'),
				'22'  => esc_html__('Hubspot','ampforwp_optin'),
				'23'  => esc_html__('MailPoet3','ampforwp_optin'),
				'24'  => esc_html__('SG Autorepondeur','ampforwp_optin'),
				'25'  => esc_html__('iterable','ampforwp_optin'),
				'26'  => esc_html__('Mailmunch','ampforwp_optin')



			),
		) );

// 1. MailChimp    
    $cmb_object->add_field( array(
		'name' => esc_html__( 'API URL', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_1_API_URL',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '1' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-1'
	) );

	$cmb_object->add_field( array(
		'desc' => 'Tutorial: <a href="http://ampforwp.com/tutorials/mailchimp-in-amp/">How to create Mailchimp form in AMP?</a>',
		'type' => 'title',
		'id'   => 'amp_optin_form_1_tutorial',
		'classes' => 'optin-form-fields amp_optin_form_tutorial optin-field-1' 
	) );

// 2. GetResponse        
    $cmb_object->add_field( array(
		'name' => esc_html__( 'Campaign Token ID', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_2_feild_one',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '2' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-2'
	) );

	$cmb_object->add_field( array(
		'desc' => 'Tutorial: <a href="http://ampforwp.com/tutorials/getresponse-in-amp/">How to create GetResponse form in AMP?</a>',
		'type' => 'title',
		'id'   => 'amp_optin_form_2_tutorial', 
		'classes' => 'optin-form-fields amp_optin_form_tutorial optin-field-2'
	) );

// 3. CM        
    $cmb_object->add_field( array(
		'name' => esc_html__( 'Company Name', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_3_feild_two',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '3' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-3'
	) );

    $cmb_object->add_field( array(
		'name' => esc_html__( 'List ID', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_3_feild_one',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '3' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-3'
	) );
	$cmb_object->add_field( array(
		'desc' => 'Tutorial: <a href="https://ampforwp.com/tutorials/article/how-to-create-campaign-monitor-form-in-amp/">How to create Campaign Monitor form in AMP?</a>',
		'type' => 'title',
		'id'   => 'amp_optin_form_3_tutorial', 
		'classes' => 'optin-form-fields amp_optin_form_tutorial optin-field-3'
	) );


// 4. Mailerlite        
    $cmb_object->add_field( array(
		'name' => esc_html__( 'API URL', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_4_feild_one',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '4' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-4'
	) );

    
    $cmb_object->add_field( array(
		'desc' => 'Tutorial: <a href="http://ampforwp.com/tutorials/mailerlite-in-amp/">How to create Mailerlite form in AMP?</a>',
		'type' => 'title',
		'id'   => 'amp_optin_form_4_tutorial', 
		'classes' => 'optin-form-fields amp_optin_form_tutorial optin-field-4'
	) );

// 5. Active Campaign    
    $cmb_object->add_field( array(
		'name' => esc_html__( 'Form URL', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_5_API_URL',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '5' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-5'
	) );
    
    $cmb_object->add_field( array(
		'name' => esc_html__( 'Form ID for Lists', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_5_FORM_ID',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '5' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-5'
	) );

	$cmb_object->add_field( array(
		'desc' => 'Tutorial: <a href="https://ampforwp.com/tutorials/article/active-campaign-in-amp/">How to create Active Campaign form in AMP?</a>',
		'type' => 'title',
		'id'   => 'amp_optin_form_5_tutorial',
		'classes' => 'optin-form-fields amp_optin_form_tutorial optin-field-5' 
	) );

// 6. Sendy    
    $cmb_object->add_field( array(
		'name' => esc_html__( 'Form URL', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_6_URL',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '6' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-6'
	) );
    
    $cmb_object->add_field( array(
		'name' => esc_html__( 'List ID', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_6_LIST_ID',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '6' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-6'
	) );

	$cmb_object->add_field( array(
		'desc' => 'Tutorial: <a href="http://ampforwp.com/tutorials/sendy-in-amp/">How to create Sendy form in AMP?</a>',
		'type' => 'title',
		'id'   => 'amp_optin_form_6_tutorial',
		'classes' => 'optin-form-fields amp_optin_form_tutorial optin-field-6' 
	) );	

// 7. ConvertKit   
    $cmb_object->add_field( array(
		'name' => esc_html__( 'ID', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_7_LIST_ID',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '7' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-7'
	) );

	$cmb_object->add_field( array(
		'desc' => 'Tutorial: <a href="http://ampforwp.com/tutorials/convertkit-in-amp/">How to create ConvertKit form in AMP?</a>',
		'type' => 'title',
		'id'   => 'amp_optin_form_7_tutorial',
		'classes' => 'optin-form-fields amp_optin_form_tutorial optin-field-7' 
	) );	

// 8. AWeber      
    $cmb_object->add_field( array(
		'name' => esc_html__( 'Form URL', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_8_form_url',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '8' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-8'
	) );
 

	$cmb_object->add_field( array(
		'desc' => 'Tutorial: <a href="https://ampforwp.com/tutorials/article/aweber-in-amp/" target="_blank">How to create AWeber form in AMP?</a>',
		'type' => 'title',
		'id'   => 'amp_optin_form_8_tutorial',
		'classes' => 'optin-form-fields amp_optin_form_tutorial optin-field-8' 
	) );

	// 9. RD Station    #15  
    $cmb_object->add_field( array(
		'name' => esc_html__( 'Token ID', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_9_token_id',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '9' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-9'
	) ); 

	$cmb_object->add_field( array(
		'name' => esc_html__( 'Identificador', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_9_identificador_id',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '9' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-9'
	) ); 

	$cmb_object->add_field( array(
		'desc' => 'Tutorial: <a href="http://ampforwp.com/tutorials/rdstation-in-amp/">How to create RD Station form in AMP?</a>',
		'type' => 'title',
		'id'   => 'amp_optin_form_9_tutorial',
		'classes' => 'optin-form-fields amp_optin_form_tutorial optin-field-9' 
	) ); 

	// 10. MailPoet    #6
    $cmb_object->add_field( array(
		'name' => esc_html__( 'Form ID', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_10_form_id',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '10' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-10'
	) );
	
	$cmb_object->add_field( array(
		'name' => esc_html__( 'List ID', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_10_list_id',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '10' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-10'
	) ); 

	$cmb_object->add_field( array(
		'desc' => 'Tutorial: <a href="http://ampforwp.com/tutorials/mailpoet-in-amp/">How to create MailPoet form in AMP?</a>',
		'type' => 'title',
		'id'   => 'amp_optin_form_10_tutorial',
		'classes' => 'optin-form-fields amp_optin_form_tutorial optin-field-10' 
	) );//Pegazee

	// 11. Benchmark
    $cmb_object->add_field( array(
		'name' => esc_html__( 'Form Name', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_11_form_name',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '11' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-11'
	) );
	
	$cmb_object->add_field( array(
		'name' => esc_html__( 'Token', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_11_token',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '11' ) ),
		'type' => 'textarea',
		'classes' => 'optin-form-fields optin-field-11'
	) ); 

	$cmb_object->add_field( array(
		'desc' => 'Tutorial: <a href="https://ampforwp.com/tutorials/article/create-benchmark-optin-form-amp/">How to create Benchmark form in AMP?</a>',
		'type' => 'title',
		'id'   => 'amp_optin_form_11_tutorial',
		'classes' => 'optin-form-fields amp_optin_form_tutorial optin-field-11' 
	) );

	// 12. GetDrip
    $cmb_object->add_field( array(
		'name' => esc_html__( 'Form ID', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_12_form_id',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '12' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-12'
	) );
	
	$cmb_object->add_field( array(
		'desc' => 'Tutorial: <a href="https://ampforwp.com/tutorials/article/how-to-use-getdrip-integration-in-amp-opt-in/">How to create GetDrip optin form in AMP?</a>',
		'type' => 'title',
		'id'   => 'amp_optin_form_12_tutorial',
		'classes' => 'optin-form-fields amp_optin_form_tutorial optin-field-12' 
	) );

	// 13. Mautic Integration
   $cmb_object->add_field(array(
         'name' => esc_html__( 'Form URL', 'ampforwp_optin' ),
         'id'=> 'amp_optin_form_13_mautic_url',
         'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '13' ) ),
         'type' => 'text',
        'classes' => 'optin-form-fields optin-field-13'
   	));
   $cmb_object->add_field( array(
		'name' => esc_html__( 'Form ID', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_13_Form_ID',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '13' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-13'
	  ));
    $cmb_object->add_field( array(
		'name' => esc_html__( 'Form Name', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_13_form_name',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '13' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-13'
	) );
	$cmb_object->add_field( array(
		'desc' => 'Tutorial: <a href="https://ampforwp.com/tutorials/article/how-to-use-mautic-integration-in-amp-opt-in/">How to create Mautic optin form in AMP?</a>',
		'type' => 'title',
		'id'   => 'amp_optin_form_13_tutorial',
		'classes' => 'optin-form-fields amp_optin_form_tutorial optin-field-13' 
	) );

	//  14. SendinBlue Integration
   
   $cmb_object->add_field(array(
         'name' => esc_html__( 'Form URL', 'ampforwp_optin' ),
         'id'=> 'amp_optin_form_14_form_url',
         'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '14' ) ),
         'type' => 'text',
        'classes' => 'optin-form-fields optin-field-14'
   	));

   $cmb_object->add_field( array(
		'desc' => 'Tutorial: <a href="https://ampforwp.com/tutorials/article/how-to-integrate-sendinblue-in-amp/">How to create Sendin optin form in AMP?</a>',
		'type' => 'title',
		'id'   => 'amp_optin_form_14_tutorial',
		'classes' => 'optin-form-fields amp_optin_form_tutorial optin-field-14' 
	) );

   /*$cmb_object->add_field( array(
		'name' => esc_html__( 'List ID', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_14_List_ID',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '14' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-14'
	  ));
   $cmb_object->add_field( array(
		'name' => esc_html__( 'Form Name', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_14_Form_Name',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '14' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-14'
	  ));
    $cmb_object->add_field( array(
		'name' => esc_html__( 'Forward URL', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_14_forward_url',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '14' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-14'
	  ));

$cmb_object->add_field( array(
		'name' => esc_html__( 'FormID', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_14_form_id',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '14' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-14'
	  ));*/
 // 15. Ontraport
    $cmb_object->add_field( array(
		'name' => esc_html__( 'UID', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_15_uid',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '15' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-15'
	) );
	$cmb_object->add_field( array(
		'name' => esc_html__( 'Mopsbbk', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_15_mopsbbk',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '15' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-15'
	) );
	
	$cmb_object->add_field( array(
		'desc' => 'Tutorial: <a href="https://ampforwp.com/tutorials/article/how-to-implement-the-otraport-opt-in-form-in-amp-opt-in-form-extension/">How to create Ontraport optin form in AMP?</a>',
		'type' => 'title',
		'id'   => 'amp_optin_form_15_tutorial',
		'classes' => 'optin-form-fields amp_optin_form_tutorial optin-field-15' 
	) );


	// 16. Sharp Spring

    $cmb_object->add_field( array(
		'name' => esc_html__( 'Form URL', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_16_form_URL',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '16' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-16'
	) );


	$cmb_object->add_field( array(
		'name' => esc_html__( 'width', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_16_form_width',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '16' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-16'
	) );
	
	$cmb_object->add_field( array(
		'name' => esc_html__( 'Height', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_16_form_height',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '16' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-16'
	) );

	$cmb_object->add_field( array(
		'desc' => 'Tutorial: <a href="https://ampforwp.com/tutorials/article/how-to-create-sharpspring-form-in-amp/">How to create SharpSpring form in AMP?</a>',
		'type' => 'title',
		'id'   => 'amp_optin_form_16_tutorial',
		'classes' => 'optin-form-fields amp_optin_form_tutorial optin-field-16' 
	) );

// 17. E-goi

    $cmb_object->add_field( array(
		'name' => esc_html__( 'Form Link', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_17_form_URL',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '17' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-17'
	) );

	$cmb_object->add_field( array(
		'desc' => 'Please remove the <b>HTTP:</b> from the provided URL and paste the rest here',
		'type' => 'title',
		'id'   => 'amp_optin_form_17_remove_http',
		'classes' => 'optin-form-fields amp_optin_form_tutorial optin-field-17' 
	) );

	$cmb_object->add_field( array(
		'name' => esc_html__( 'List ID', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_17_form_lista',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '17' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-17'
	) );
	
	$cmb_object->add_field( array(
		'name' => esc_html__( 'Client ID', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_17_form_client',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '17' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-17'
	) );
	
	$cmb_object->add_field( array(
		'name' => esc_html__( 'FormID', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_17_form_formid',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '17' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-17'
	) );
	$cmb_object->add_field( array(
		'name' => esc_html__( 'Name-Field ID', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_17_form_namefid',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '17' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-17'
	) );

	$cmb_object->add_field( array(
		'name' => esc_html__( 'Email-Field ID', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_17_form_emailfid',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '17' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-17'
	) );

	
	$cmb_object->add_field( array(
		'desc' => 'Tutorial: <a href="https://ampforwp.com/tutorials/article/how-to-create-e-goi-form-in-amp/">How to create E-goi form in AMP?</a>',
		'type' => 'title',
		'id'   => 'amp_optin_form_17_tutorial',
		'classes' => 'optin-form-fields amp_optin_form_tutorial optin-field-17' 
	) );
    
    //18. MailJet

    $cmb_object->add_field( array(
		'name' => esc_html__( 'Form URL', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_18_form_URL',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '18' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-18'
	) );


	$cmb_object->add_field( array(
		'name' => esc_html__( 'width', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_18_form_width',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '18' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-18'
	) );
	
	$cmb_object->add_field( array(
		'name' => esc_html__( 'Height', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_18_form_height',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '18' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-18'
	) );

	$cmb_object->add_field( array(
		'desc' => 'Tutorial: <a href="https://ampforwp.com/tutorials/article/how-to-use-mailjet-integration-in-amp-opt-in/">How to create MailJet form in AMP?</a>',
		'type' => 'title',
		'id'   => 'amp_optin_form_18_tutorial',
		'classes' => 'optin-form-fields amp_optin_form_tutorial optin-field-18' 
	) );


	// 19. iPost

    $cmb_object->add_field( array(
		'name' => esc_html__( 'Form Action URL', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_19_form_action',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '19' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-19'
	) );

	$cmb_object->add_field( array(
		'name' => esc_html__( 'Sub Client', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_19_sub_client',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '19' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-19'
	) );
	
	$cmb_object->add_field( array(
		'name' => esc_html__( 'Source Code', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_19_source_code',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '19' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-19'
	) );

	$cmb_object->add_field( array(
		'desc' => 'Tutorial: <a href="https://ampforwp.com/tutorials/article/how-to-create-ipost-form-in-amp/">How to create iPost form in AMP?</a>',
		'type' => 'title',
		'id'   => 'amp_optin_form_19_tutorial',
		'classes' => 'optin-form-fields amp_optin_form_tutorial optin-field-19' 
	) );

// 20 infusionsoft code//
    $cmb_object->add_field( array(
		'name' => esc_html__( 'Form Name', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_20_form_name',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '20' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-20'
	) ); 
	$cmb_object->add_field( array(
		'name' => esc_html__( 'Form URL', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_20_form_url',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '20' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-20'
	) ); 
	$cmb_object->add_field( array(
		'name' => esc_html__( 'Form ID', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_20_form_id',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '20' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-20'
	) ); 
	$cmb_object->add_field( array(
		'name' => esc_html__( 'Infusionsoft version', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_20_form_version',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '20' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-20'
	) );

	$cmb_object->add_field( array(
			'desc' => 'Tutorial: <a href="https://ampforwp.com/tutorials/article/how-to-integrate-infusion-soft-newsletter-company-in-amp-using-amp-optin-extension/">How to create Infusionsoft form in AMP?</a>',
		'type' => 'title',
		'id'   => 'amp_optin_form_20_tutorial',
		'classes' => 'optin-form-fields amp_optin_form_tutorial optin-field-20' 
	) );

//21. Constant Contact
	$cmb_object->add_field( array(
		'name' => esc_html__( 'Form URL', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_21_form_url',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '21' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-21'
	) ); 
	 $cmb_object->add_field( array(
		'name' => esc_html__( 'Form ID', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_21_form_id',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '21' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-21'
	) ); 
	$cmb_object->add_field( array(
		'name' => esc_html__( 'List ID', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_21_list_id',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '21' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-21'
	) ); 
	$cmb_object->add_field( array(
		'name' => esc_html__( 'Hidden ID 1', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_21_hidden_id_1',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '21' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-21'
	) );
	$cmb_object->add_field( array(
		'name' => esc_html__( 'Hidden ID 2', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_21_hidden_id_2',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '21' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-21'
	) );
	$cmb_object->add_field( array(
			'desc' => 'Tutorial: <a href="https://ampforwp.com/tutorials/article/how-to-use-constantcontact-in-amp-opt-in/">How to create Constant Contact opt-in form in AMP?</a>',
		'type' => 'title',
		'id'   => 'amp_optin_form_21_tutorial',
		'classes' => 'optin-form-fields amp_optin_form_tutorial optin-field-21' 
	) );

	//22. Hubspot Integration
	$cmb_object->add_field( array(
		'name' => esc_html__( 'Form URL', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_22_form_url',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '22' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-22'
	) );
	$cmb_object->add_field( array(
			'desc' => 'Tutorial: <a href="https://ampforwp.com/tutorials/article/how-to-use-hubspot-integration-in-amp-opt-in/">How to create Hubspot opt-in form in AMP?</a>',
		'type' => 'title',
		'id'   => 'amp_optin_form_22_tutorial',
		'classes' => 'optin-form-fields amp_optin_form_tutorial optin-field-22' 
	) );
	

//23. MailPoet3 Compatibility.
	$cmb_object->add_field( array(
		'name' => esc_html__( 'Name [ First Name ]', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_23_first_name',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '23' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-23'
	) );

	$cmb_object->add_field( array(
		'name' => esc_html__( 'Name [ Last Name ]', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_23_Last_Name',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '23' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-23'
	) );
	$cmb_object->add_field( array(
		'name' => esc_html__( 'Email Name', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_23_email_id',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '23' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-23'
	) );
	$cmb_object->add_field( array(
		'name' => esc_html__( 'Form ID', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_23_form_id',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '23' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-23'
	) );
	$cmb_object->add_field( array(
		'name' => esc_html__( 'Token', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_23_Token',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '23' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-23'
	) );
	$cmb_object->add_field( array(
		'name' => esc_html__( 'Api version', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_23_Api_version',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '23' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-23'
	) );
	$cmb_object->add_field( array(
		'desc' => 'Tutorial: <a href="https://ampforwp.com/tutorials/article/how-to-setup-mailpoet3-in-amp/">How to create MailPoet3 form in AMP?</a>',
		'type' => 'title',
		'id'   => 'amp_optin_form_23_tutorial',
		'classes' => 'optin-form-fields amp_optin_form_tutorial optin-field-23' 
	) );


	//24. SG Autorepondeur Integration
	$cmb_object->add_field( array(
		'name' => esc_html__( 'User ID', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_24_user_id',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '24' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-24'
	) );
	$cmb_object->add_field( array(
		'name' => esc_html__( 'List ID', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_24_list_id',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '24' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-24'
	) );
	$cmb_object->add_field( array(
		'name' => esc_html__( 'Form ID', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_24_form_id',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '24' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-24'
	) );
	$cmb_object->add_field( array(
		'desc' => 'Tutorial: <a href="https://ampforwp.com/tutorials/article/how-to-create-sg-autorepondeur-form-in-amp/">How to create SG Autorepondeur form in AMP</a>',
		'type' => 'title',
		'id'   => 'amp_optin_form_24_tutorial',
		'classes' => 'optin-form-fields amp_optin_form_tutorial optin-field-24' 
	) );
	//25. Iterable Integration
	$cmb_object->add_field( array(
		'name' => esc_html__( 'Form URL', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_25_form_url',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '25' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-25'
	) );

	// 26. Mailmunch.   
    $cmb_object->add_field( array(
		'name' => esc_html__( 'API URL', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_26_API_URL',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '26' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-26'
	) );

	$cmb_object->add_field( array(
		'name' => esc_html__( 'First Name ID', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_26_Name_ID',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '26' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-26'
	) );
	$cmb_object->add_field( array(
		'name' => esc_html__( 'First Name Value', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_26_Name_Value',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '26' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-26'
	) );
	$cmb_object->add_field( array(
		'name' => esc_html__( 'Last Name ID', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_26_last_Name_ID',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '26' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-26'
	) );
	$cmb_object->add_field( array(
		'name' => esc_html__( 'Last Name Value', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_26_last_Name_Value',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '26' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-26'
	) );
	$cmb_object->add_field( array(
		'name' => esc_html__( 'Email ID', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_26_email_id',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '26' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-26'
	) );
	$cmb_object->add_field( array(
		'name' => esc_html__( 'Email Value', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_26_email_value',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '26' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-26'
	) );

	$cmb_object->add_field( array(
		'name' => esc_html__( 'phone ID', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_26_phone_id',
		'show_on'      => array( 'key' => 'amp_optin_phone_hide', 'value' => array( '1' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-26 optin-form-fields-phone'
	) );

	$cmb_object->add_field( array(
		'name' => esc_html__( 'Phone Value', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_26_phone_value',
		'show_on'      => array( 'key' => 'amp_optin_phone_hide', 'value' => array( '1' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields optin-field-26 optin-form-fields-phone'
	) );
	
	$cmb_object->add_field( array(
		'name' => esc_html__( 'Select Field ID', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_26_Select_id',
		'show_on'      => array( 'key' => 'amp_optin_Select_Field_hide', 'value' => array( '1' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields-Select_field'
	) );

	$cmb_object->add_field( array(
		'name' => esc_html__( 'Select Field Value', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_26_Select_value',
		'show_on'      => array( 'key' => 'amp_optin_Select_Field_hide', 'value' => array( '1' ) ),
		'type' => 'text',
		'classes' => 'optin-form-fields-Select_field'
	) );
	
	$cmb_object->add_field( array(
		'desc' => 'Tutorial: <a href="https://ampforwp.com/tutorials/article/how-to-create-mailmunch-form-in-amp/" target="_blank">How to create Mailmunch form in AMP</a>',
		'type' => 'title',
		'id'   => 'amp_optin_form_26_tutorial',
		'classes' => 'optin-form-fields amp_optin_form_tutorial optin-field-26' 
	) );


// Company specific opt-in Fields End here

	$cmb_object->add_field( array(
		'name' => 'Headline Message',
		'desc' => 'Write the message that comes along with the opt-in form.',
		'type' => 'title',
		'id'   => 'amp_optin_headline_title',
	) );

	$cmb_object->add_field( array(
		'name' => esc_html__( 'Title', 'ampforwp_optin' ),
		'id'   => 'ampforwp_optin_title',
        'default' => 'Headline Title',
		'type' => 'text',
//		'classes' => 'optin-form-fields optin-field-1'
	) );


	$cmb_object->add_field( array(
		'name' => esc_html__( 'Description', 'ampforwp_optin' ),
		'id'   => 'ampforwp_optin_desccription',
        'default' => 'Headline description goes here',
		'type' => 'text',
//		'classes' => 'optin-form-fields optin-field-1'
	) );

	$cmb_object->add_field( array(
		'name'             => esc_html__( 'Visual Editor', 'ampforwp_optin' ),
		'id'               => 'amp_optin_checkbox',
		'type'             => 'checkbox',
		'show_option_none' => false,
		'default' 		   => '0',
		'options'          => array(
						'0'=>0,
						'1'   => esc_html__( 'wysiwyg', 'ampforwp_optin' ),
		),
	) );
 
   
    $cmb_object->add_field( array(
		'name' => esc_html__( '', 'ampforwp_optin' ),
		'id'   => 'amp_optin_wysiwyg',
		'show_on'      => array( 'key' => 'amp_optin_checkbox', 'value' =>   array('1')  ),
		'type' => 'wysiwyg',
		'classes' => 'optin-form-fields-wysiwyg',
	) );
 	
 	$cmb_object->add_field( array(
		'name'             => esc_html__( 'Redirection', 'ampforwp_optin' ),
		'id'               => 'amp_optin_checkbox_redirect',
		'type'             => 'checkbox',
		'show_option_none' => false,
		'default' 		   => '0',
		'options'          => array(
						'0'=>0,
						'1'   => esc_html__( 'text', 'ampforwp_optin' ),
		),

		'classes'		=> array(
			'optin-form-fields optin-field-1',
			'optin-form-fields optin-field-2',
			'optin-form-fields optin-field-4',
			'optin-form-fields optin-field-5',
			'optin-form-fields optin-field-6',
			'optin-form-fields optin-field-7',
			'optin-form-fields optin-field-9',
			'optin-form-fields optin-field-13',
			'optin-form-fields optin-field-15',
			'optin-form-fields optin-field-17',
			'optin-form-fields optin-field-19',
			'optin-form-fields optin-field-21',
			'optin-form-fields optin-field-24',
			'optin-form-fields optin-field-25',
			'optin-form-fields optin-field-26',
		)
	) );
    $cmb_object->add_field( array(
		'name' => esc_html__( 'Redirect URL', 'ampforwp_optin' ),
		'id'   => 'ampforwp_optin_redirection',
		'show_on'  => array( 'key' => 'amp_optin_checkbox_redirect', 'value' =>   array('1')  ),
        'placeholder' => 'Enter the URL to redirect the optin form',
		'type' => 'text',
		'classes' => 'optin-form-fields-redirect',
	) );

	$cmb_object->add_field( array(
		'name'             => esc_html__( 'fullname', 'ampforwp_optin' ),
		'id'               => 'amp_optin_fullname_hide',
		'type'             => 'checkbox',
		'show_option_none' => false,
		'default' 		   => '0',
		'options'          => array(
						'0'=>0,
						'1'   => esc_html__( 'fullname', 'ampforwp_optin' ),
		),

		'classes'		=> array(
			'optin-form-fields optin-field-1',
			'optin-form-fields optin-field-2',
			'optin-form-fields optin-field-4',
			'optin-form-fields optin-field-5',
			'optin-form-fields optin-field-6',
			'optin-form-fields optin-field-7',
			'optin-form-fields optin-field-9',
			'optin-form-fields optin-field-13',
			'optin-form-fields optin-field-15',
			'optin-form-fields optin-field-17',
			'optin-form-fields optin-field-19',
			'optin-form-fields optin-field-21',
		)
	) );
    $cmb_object->add_field( array(
		'name' => esc_html__( 'fullname', 'ampforwp_optin' ),
		'id'   => 'ampforwp_optin_fullname',
		'show_on'  => array( 'key' => 'amp_optin_fullname_hide', 'value' =>   array('1')  ),
        'placeholder' => 'fullname',
		'type' => 'text',
		'classes' => 'optin-form-fields-fullname',
	) );

$cmb_object->add_field( array(
		'name'             => esc_html__( 'phone', 'ampforwp_optin' ),
		'id'               => 'amp_optin_phone_hide',
		'type'             => 'checkbox',
		'show_option_none' => false,
		'default' 		   => '0',
		'options'          => array(
						'0'=>0,
						'1'   => esc_html__( 'phone', 'ampforwp_optin' ),
		),

		'classes'		=> array(
			'optin-form-fields optin-field-1',
			'optin-form-fields optin-field-2',
			'optin-form-fields optin-field-4',
			'optin-form-fields optin-field-5',
			'optin-form-fields optin-field-6',
			'optin-form-fields optin-field-7',
			'optin-form-fields optin-field-9',
			'optin-form-fields optin-field-13',
			'optin-form-fields optin-field-15',
			'optin-form-fields optin-field-17',
			'optin-form-fields optin-field-19',
			'optin-form-fields optin-field-21',
			'optin-form-fields optin-field-26',
		)
	) );

    $cmb_object->add_field( array(
		'name' => esc_html__( 'phone', 'ampforwp_optin' ),
		'id'   => 'ampforwp_optin_phone',
		'show_on'  => array( 'key' => 'amp_optin_phone_hide', 'value' =>   array('1')  ),
        'placeholder' => 'phone',
		'type' => 'text',
		'classes' => 'optin-form-fields-phone',
	) );
	//select f-26.
$cmb_object->add_field( array(
		'name'             => esc_html__( 'Select Field', 'ampforwp_optin' ),
		'id'               => 'amp_optin_Select_Field_hide',
		'type'             => 'checkbox',
		'show_option_none' => false,
		'default' 		   => '0',
		'options'          => array(
						'0'=>0,
						'1'   => esc_html__( 'phone', 'ampforwp_optin' ),
		),

		'classes'		=> array(
			'optin-form-fields optin-field-26',
		)
	) );

	$cmb_object->add_field( array(
		'name'             => esc_html__( 'PRODUCT', 'ampforwp_optin' ),
		'id'               => 'amp_optin_PRODUCT_hide',
		'type'             => 'checkbox',
		'show_option_none' => false,
		'default' 		   => '0',
		'options'          => array(
						'0'=>0,
						'1'   => esc_html__( 'PRODUCT', 'ampforwp_optin' ),
		),

		'classes'		=> array(
			'optin-form-fields optin-field-1',
			'optin-form-fields optin-field-2',
			'optin-form-fields optin-field-4',
			'optin-form-fields optin-field-5',
			'optin-form-fields optin-field-6',
			'optin-form-fields optin-field-7',
			'optin-form-fields optin-field-9',
			'optin-form-fields optin-field-13',
			'optin-form-fields optin-field-15',
			'optin-form-fields optin-field-17',
			'optin-form-fields optin-field-19',
			'optin-form-fields optin-field-21',
		)
	) );
    $cmb_object->add_field( array(
		'name' => esc_html__( 'PRODUCT', 'ampforwp_optin' ),
		'id'   => 'ampforwp_optin_PRODUCT',
		'show_on'  => array( 'key' => 'amp_optin_PRODUCT_hide', 'value' =>   array('1')  ),
        'placeholder' => 'PRODUCT',
		'type' => 'text',
		'classes' => 'optin-form-fields-PRODUCT',
	) );

	$cmb_object->add_field( array(
		'name'             => esc_html__( 'OrderID', 'ampforwp_optin' ),
		'id'               => 'amp_optin_OrderID_hide',
		'type'             => 'checkbox',
		'show_option_none' => false,
		'default' 		   => '0',
		'options'          => array(
						'0'=>0,
						'1'   => esc_html__( 'OrderID', 'ampforwp_optin' ),
		),

		'classes'		=> array(
			'optin-form-fields optin-field-1',
			'optin-form-fields optin-field-2',
			'optin-form-fields optin-field-4',
			'optin-form-fields optin-field-5',
			'optin-form-fields optin-field-6',
			'optin-form-fields optin-field-7',
			'optin-form-fields optin-field-9',
			'optin-form-fields optin-field-13',
			'optin-form-fields optin-field-15',
			'optin-form-fields optin-field-17',
			'optin-form-fields optin-field-19',
			'optin-form-fields optin-field-21',
		)
	) );
    $cmb_object->add_field( array(
		'name' => esc_html__( 'OrderID', 'ampforwp_optin' ),
		'id'   => 'ampforwp_optin_OrderID',
		'show_on'  => array( 'key' => 'amp_optin_OrderID_hide', 'value' =>   array('1')  ),
        'placeholder' => 'OrderID',
		'type' => 'text',
		'classes' => 'optin-form-fields-OrderID',
	) );

	$cmb_object->add_field( array(
		'name'             => esc_html__( 'Gdpr', 'ampforwp_optin' ),
		'id'               => 'amp_optin_Gdpr_hide',
		'type'             => 'checkbox',
		'show_option_none' => false,
		'default' 		   => '0',
		'options'          => array(
						'0'=>0,
						'1'   => esc_html__( 'Gdpr', 'ampforwp_optin' ),
		),

		'classes'		=> array(
			'optin-form-fields optin-field-1',
			'optin-form-fields optin-field-2',
			'optin-form-fields optin-field-4',
			'optin-form-fields optin-field-5',
			'optin-form-fields optin-field-6',
			'optin-form-fields optin-field-7',
			'optin-form-fields optin-field-9',
			'optin-form-fields optin-field-13',
			'optin-form-fields optin-field-15',
			'optin-form-fields optin-field-17',
			'optin-form-fields optin-field-19',
			'optin-form-fields optin-field-21',
		)
	) );
    $cmb_object->add_field( array(
		'name' => esc_html__( 'Gdpr', 'ampforwp_optin' ),
		'id'   => 'ampforwp_optin_Gdpr',
		'show_on'  => array( 'key' => 'amp_optin_Gdpr_hide', 'value' =>   array('1')  ),
        'placeholder' => 'Gdpr',
		'type' => 'text',
		'classes' => 'optin-form-fields-Gdpr',
	) );

	$cmb_object->add_field( array(
		'name'             => esc_html__( 'DateofPurchase', 'ampforwp_optin' ),
		'id'               => 'amp_optin_DateofPurchase_hide',
		'type'             => 'checkbox',
		'show_option_none' => false,
		'default' 		   => '0',
		'options'          => array(
						'0'=>0,
						'1'   => esc_html__( 'DateofPurchase', 'ampforwp_optin' ),
		),

		'classes'		=> array(
			'optin-form-fields optin-field-1',
			'optin-form-fields optin-field-2',
			'optin-form-fields optin-field-4',
			'optin-form-fields optin-field-5',
			'optin-form-fields optin-field-6',
			'optin-form-fields optin-field-7',
			'optin-form-fields optin-field-9',
			'optin-form-fields optin-field-13',
			'optin-form-fields optin-field-15',
			'optin-form-fields optin-field-17',
			'optin-form-fields optin-field-19',
			'optin-form-fields optin-field-21',
		)
	) );
    $cmb_object->add_field( array(
		'name' => esc_html__( 'DateofPurchase', 'ampforwp_optin' ),
		'id'   => 'ampforwp_optin_DateofPurchase',
		'show_on'  => array( 'key' => 'amp_optin_DateofPurchase_hide', 'value' =>   array('1')  ),
        'placeholder' => 'DateofPurchase',
		'type' => 'text',
		'classes' => 'optin-form-fields-DateofPurchase',
	) );
	
$cmb_object->add_field( array(
		'name'             => esc_html__( 'COUNTRY', 'ampforwp_optin' ),
		'id'               => 'amp_optin_COUNTRY_hide',
		'type'             => 'checkbox',
		'show_option_none' => false,
		'default' 		   => '0',
		'options'          => array(
						'0'=>0,
						'1'   => esc_html__( 'COUNTRY', 'ampforwp_optin' ),
		),

		'classes'		=> array(
			'optin-form-fields optin-field-1',
			'optin-form-fields optin-field-2',
			'optin-form-fields optin-field-4',
			'optin-form-fields optin-field-5',
			'optin-form-fields optin-field-6',
			'optin-form-fields optin-field-7',
			'optin-form-fields optin-field-9',
			'optin-form-fields optin-field-13',
			'optin-form-fields optin-field-15',
			'optin-form-fields optin-field-17',
			'optin-form-fields optin-field-19',
			'optin-form-fields optin-field-21',
		)
	) );
    $cmb_object->add_field( array(
		'name' => esc_html__( 'COUNTRY', 'ampforwp_optin' ),
		'id'   => 'ampforwp_optin_COUNTRY',
		'show_on'  => array( 'key' => 'amp_optin_COUNTRY_hide', 'value' =>   array('1')  ),
        'placeholder' => 'COUNTRY',
		'type' => 'text',
		'classes' => 'optin-form-fields-COUNTRY',
	) );
	$cmb_object->add_field( array(
		'name' => esc_html__( 'Email Address', 'ampforwp_optin' ),
		'default'   => 'Email Address',
		'id'   => 'amp_optin_form_1_email_address',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '1' ) ),
		'type' => 'text',
		'classes' => array(
			'optin-form-fields optin-field-1',
			'optin-form-fields optin-field-2',
			'optin-form-fields optin-field-4',
			'optin-form-fields optin-field-5',
			'optin-form-fields optin-field-6',
			'optin-form-fields optin-field-7',
			'optin-form-fields optin-field-9',
			'optin-form-fields optin-field-10',
			'optin-form-fields optin-field-11',
			'optin-form-fields optin-field-12',
			'optin-form-fields optin-field-13',
			'optin-form-fields optin-field-14',
			'optin-form-fields optin-field-15',
			'optin-form-fields optin-field-16',
			'optin-form-fields optin-field-17',
			'optin-form-fields optin-field-18',
			'optin-form-fields optin-field-19',			
			'optin-form-fields optin-field-21',	
			'optin-form-fields optin-field-26',		
		)
	) );

	$cmb_object->add_field( array(
		'name' => esc_html__( 'First Name', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_1_first_name',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '1' ) ),
		'type' => 'text',
        'default' => 'First Name',
		'classes' => array(
			'optin-form-fields optin-field-1',
			'optin-form-fields optin-field-2',
			'optin-form-fields optin-field-4',
			'optin-form-fields optin-field-5',
			'optin-form-fields optin-field-6',
			'optin-form-fields optin-field-9',
			'optin-form-fields optin-field-10',
			'optin-form-fields optin-field-11',
			'optin-form-fields optin-field-12',
			'optin-form-fields optin-field-13',
			'optin-form-fields optin-field-14',
			'optin-form-fields optin-field-15',
			'optin-form-fields optin-field-16',
			'optin-form-fields optin-field-17',
			'optin-form-fields optin-field-18',
			'optin-form-fields optin-field-19',
			'optin-form-fields optin-field-21',
			'optin-form-fields optin-field-24',
			'optin-form-fields optin-field-25',
			'optin-form-fields optin-field-23',
			'optin-form-fields optin-field-26',
		)
	) ); 

	$cmb_object->add_field( array(
		'name'             => esc_html__( 'Hide', 'ampforwp_optin' ),
		'id'               => 'amp_optin_first_name_hide',
		'type'             => 'checkbox',
		'show_option_none' => false,
		'default' 		   => '0',
		'classes' => array(
			'optin-form-fields optin-field-1',
			'optin-form-fields optin-field-2',
			'optin-form-fields optin-field-4',
			'optin-form-fields optin-field-5',
			'optin-form-fields optin-field-6',
			'optin-form-fields optin-field-9',
			'optin-form-fields optin-field-10',
			'optin-form-fields optin-field-11',
			'optin-form-fields optin-field-12',
			'optin-form-fields optin-field-13',
			'optin-form-fields optin-field-14',
			'optin-form-fields optin-field-15',
			'optin-form-fields optin-field-16',
			'optin-form-fields optin-field-17',
			'optin-form-fields optin-field-18',
			'optin-form-fields optin-field-19',
			'optin-form-fields optin-field-21',
			'optin-form-fields optin-field-23',
			'optin-form-fields optin-field-26',
		)
	) ); 

	
	$cmb_object->add_field( array(
		'name' => esc_html__( 'Last Name', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_1_last_name',
		'show_on'      => array( 'key' => 'amp_optin_select_form_company', 'value' => array( '1' ) ),
		'type' => 'text',
		'default' => 'Last Name',
		'classes' => array(
			'optin-form-fields optin-field-1',
			'optin-form-fields optin-field-2',
			'optin-form-fields optin-field-4',
			'optin-form-fields optin-field-5',
			'optin-form-fields optin-field-6',
			'optin-form-fields optin-field-10',
			'optin-form-fields optin-field-11',
			'optin-form-fields optin-field-13',
			'optin-form-fields optin-field-14',
			'optin-form-fields optin-field-15',
			'optin-form-fields optin-field-16',
			'optin-form-fields optin-field-17',
			'optin-form-fields optin-field-18',
			'optin-form-fields optin-field-19',
			'optin-form-fields optin-field-21',
			'optin-form-fields optin-field-23',
			'optin-form-fields optin-field-26',
				),
	) );

		$cmb_object->add_field( array(
		'name'             => esc_html__( 'Hide', 'ampforwp_optin' ),
		'id'               => 'amp_optin_last_name_hide',
		'type'             => 'checkbox',
		'show_option_none' => false,
		'default' 		   => '0',
		'classes' => array(
			'optin-form-fields optin-field-1',
			'optin-form-fields optin-field-2',
			'optin-form-fields optin-field-4',
			'optin-form-fields optin-field-5',
			'optin-form-fields optin-field-6',
			'optin-form-fields optin-field-10',
			'optin-form-fields optin-field-11',
			'optin-form-fields optin-field-13',
			'optin-form-fields optin-field-14',
			'optin-form-fields optin-field-15',
			'optin-form-fields optin-field-16',
			'optin-form-fields optin-field-17',
			'optin-form-fields optin-field-18',
			'optin-form-fields optin-field-19',
			'optin-form-fields optin-field-21',
			'optin-form-fields optin-field-23',
			'optin-form-fields optin-field-26',
			),
	) );
	$cmb_object->add_field( array(
		'name' => esc_html__( 'Submit Button', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_submit_button',
		'type' => 'text',
		'default' => 'Submit',
//		'classes' => 'optin-form-fields optin-field-1'
	) );

	$cmb_object->add_field( array(
		'name' => esc_html__( 'Success Message', 'ampforwp_optin' ),
		'id'   => 'amp_optin_form_success-msg',
		'type' => 'text',
		'default' => 'Subscription successful!', 
	) );

}